# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["DefinitionLinkParams"]


class DefinitionLinkParams(TypedDict, total=False):
    eval_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="evalIds")]]
    """Array of evaluation definition IDs to link/unlink.

    Can be a single ID or multiple IDs.
    """

    task_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="taskIds")]]
    """Array of task IDs to link/unlink the evaluation definitions to/from.

    Can be a single ID or multiple IDs.
    """
